/*cef993_cfr dataset includes 993 fund level observations, each is a CEF IPO from 1986 to 2013. It includes the following variables:
	cusip odate spread name op adr perm proceeds bhret3 matvw3 MATSTYL3 matsize3 bhret5 matvw5 matstyl5 matsize5 
		bret1hal bret2hal bret1 bret2 bret3 bret4 bret5 szret1hal szret2hal szret1 szret2 szret3 szret4 szret5
		stret1hal stret2hal stret1 stret2 stret3 stret4 stret5 cpi fulldate mm dd first20 decade crspvw15 nasdaq15. 

cusip is the CUSIP identifier, odate is the IPO year, spread is the gross spread of the IPO, name is the fund name, 
op is offer price of CEF IPO, adr is the fund type, 3 is domestic equity, 4 is foreign equity, 5 is municipal bond, 6 is taxable fixed income, 7 is other.
perm is the CRSP Permno identifier. proceeds is the proceeds of CEF IPO, not adjusted by inflation. bhret3 is the 3-year buy-and-hold return of the CEF IPO. 
matvw3 is the 3-year value-weighted market return. matstyl3 is the 3-year premium-matched seasoned fund return. 
matsize3 is the 3-year size-matched seasoned fund return. all toher return variables are annaul returns, and they are 1st-half year, 2nd-half year, 1st year, 
2nd year, 3rd year, 4th year, and 5th year, respectively. cpi is the annual cpi, where cpi of 2004 is one. fulldate is the full date of CEF IPO date. 
mm is the month of CEF IPO, dd is the day of CEF IO. 
first20 is a dummy variable that indicates whether the CEF IPO occurs during the first 20 days of a month. 
decade indicates the decade of when the CEF IPO occurs. 
crspvw15 and nasdaq15 record the 15-day return of CRSP value-weighted index and the Nasdaq index prior to the CEF IPO. */

/*cef993nav_cfr datasets includes fund-month observations, each is a monthly observation for a given CEF IPO.
 It includes the following variables: 
	permno date cusip ticker name nav price ret retcret pord premium INSTOWN_PERC adr cefmcap fulldate evtmonth4 old

	permno is the CRSP permno identifier. date is the date of observation. cusip is the CUSIP identifier. ticker is the CEF IPO ticker. 
	name is the name of the CEF IPO fund. NAV is the NAV of CEF IPO in a given month. price is the price of a CEF IPO in a given month. 
	ret is the monthly return provided by CRSP, including dividend. retcret is the cumulative return of a CEF IPO. 
	pord is the premium (or discount) of a CEF IPO at a given month, i.e. the percentage difference between price and nav. 
	premium is a dummy variable that equals 1 if the CEF IPO trades at a premium at a given month. 
	instown_perc is the institutional ownership in percentage. 
	adr is the fund asset class, adr=3 is domestic equity, =4 is foreign equity, =5 is municipal bond, =6 is taxable fixed income, 7 is other. 
	cefmcap is the market capitalization of CEF IPO at a given month. 
	fulldate is the full date of a CEF IPO. 
	evtmonth4 is the event month of a CEF IPO, starting from 0. 0 is the same month-end of the CEF IPO date. For example, if a fund goes public on June 22nd 1992, 
			June 1992 will be event month 0. 
	old is a dummy variable that indicates if the fund has been publicly traded for over 12 months. */

/*if perm in(84160,84017,84574) then delete;/ /*the three funds are open-end funds converted to closed-end*/

/*throughout the script, PorD refers to the premium (or discount) of each CEF IPO, usually on a monthly level. 
 Without further statement, premium (or discount) is the percentage difference between price and NAV. Sometimes, 
 it could be simply stated as premium in the comments, but it also include discount situation.*/

/**********************************************************************************************************/
/*******************************Figure 1, CEF IPO Premium and Sales Load by Year***************************/
/**********************************************************************************************************/

/*calculate the average and median of CEF IPOs' permium (or discount) at the end of the IPO month*/
proc sort data=cef993nav_cfr;
by ipoperm evtmonth4;
run;
/*evtmonth4 is the corrected event month relative to the CEF IPO time.
  if evtmonth4=0 it means the same month as the CEF IPO, or the calendar month end immediately after the IPO*/
proc means data=cef993nav_cfr (where=(evtmonth4<1)) noprint;
  class navyear; 
  var pord;
  output out=cef993_pordstat 
  mean= median= n= t= /autoname;
run;
proc sort data=cef993_pordstat;
by navyear;
run;
data cef993_pordstat1;
set cef993_pordstat;
if navyear=. then delete;
*if navmonth=. then delete;
pord_mean=pord_mean*100;
pord_median=pord_median*100;
format pord_mean 7.2;
format pord_median 7.2;
run;

/*calculate the average and median of sales load for CEF IPOs */
proc sort data=cef993_cfr;
by odate mm;
run;
proc means data=cef993_cfr(where=(spread>0)) noprint;
  class odate; 
  var spread;
  output out=cef993_spreadstat 
  mean= median= n= t= /autoname;
run;
proc sort data=cef993_spreadstat;
by odate;
run;
data cef993_spreadstat1;
set cef993_spreadstat;
if odate=. then delete;
format spread_mean 7.2;
format spread_median 7.2;
run;

/*merge together the sales load and the premium (or discount) at the month end of the CEF IPO and plot the mean sales load and the mean premium*/
proc sql;
create table cefspreadpremium as select a.odate, a._freq_ as n_premium,a.spread_mean,a.spread_median, b._freq_ as n_pord, b.pord_mean, b.pord_median 
                              from cef993_spreadstat1 a, cef993_pordstat1 b
							  where a.odate=b.navyear;
quit;
options nodate orientation=landscape; ods pdf file='D:\CEF\CEF IPO Spread and Discount by Year.pdf';
goptions device=pdfc; 
axis1 label=(angle=90 "CEF IPO Sales Load and Premium/Discount by Year")
      order=(0 to 9 by 1);
axis2 label=("Year of IPO")
      order=(1986 to 2013 by 1);
symbol interpol=join w=3 l=1;
proc gplot data =cefspreadpremium;
*where spread>-99;
*by type;
Title "CEF IPO Sales Load and CEF IPO Premium by Year";
 plot (spread_mean pord_mean)*odate
       /overlay legend vaxis=axis1 haxis=axis2;
run;quit; ods pdf close; 



/**********************************************************************************************************/
/*********************Figure 2, CEF Monthly Premium or Discount by Type and Event Month********************/
/**********************************************************************************************************/
proc means data=cef993nav_cfr(where=(evtmonth4<61)) noprint;
  class ADR evtmonth4; 
  var PorD;
  output out=cef993nav_stat 
  mean= n= t= sum=/autoname;
run;
proc sort data=cef993nav_stat;
by ADR evtmonth4;
run;
data cef993nav_stat1;
set cef993nav_stat;
if ADR=. then delete;
if evtmonth4=. then delete;
run;
proc sort data=cef993nav_stat1;
by pord_mean;
run;
proc sort data=cef993nav_stat1;
by ADR evtmonth4;
run;
options date orientation=landscape; ods pdf file='D:\CEF\993 CEF monthly premium discount by CEF type and Event Month.pdf';
goptions device=pdfc; /* Plot Saved in Home Directory */
axis1 label=(angle=90 "% of premium or discount between Price and NAV")
      order=(-0.10 to 0.09 by 0.02);
axis2 label=("Number of Months after a CEF Goes Public");
symbol1 interpol=join color=red value=none line=1 width=2;
symbol2 interpol=join color=green value=plus line=5 width=2;
symbol3 interpol=join color=blue value=marker line=10 width=1;
symbol4 interpol=join color=black value=star line=3 width=2;
symbol5 interpol=join color=purple value=cube line=9 width=2;
legend1 label=('Closed-end Fund Type:') value=(color=black 'Domestic Equity' 'Foreign Equity' 'Municipal Bond' 'Taxable Fixed Income' 'Other');
proc gplot data =cef993nav_stat1;
*Title "993 CEF monthly premium/discount by CEF type and Event Month";
title;
plot PorD_mean*evtmonth4=ADR
       /overlay legend=legend1 vref=0 href=6 href=3 vaxis=axis1 haxis=axis2;
run;quit; ods pdf close; 


/**********************************************************************************************************/
/*******************Figure 3, Average Monthly CEF IPO Proceeds by Seasoned Fund Premium********************/
/**********************************************************************************************************/

/*this figure was plotted using Excel, by plotting the inflation adjusted monthly average of CEF IPOs against four buckets of 
quarterly average premium of seasoned funds, i.e. from month t-3 to month t-1. or mseasonedprem=(seasonedprem3+seasonedprem2+seasonedprem1)/3.
The four buckets of average seasoned fund premium are <-10%, between -10% to -5%, between -5% to 0%, and above 0%. */

/**********************************************************************************************************/
/*******************Figure 4, Buy-and-hold Raw and Abnormal Return of CEF IPOs, 1986-2013******************/
/**********************************************************************************************************/
/*stylematchall dataset includes CEF IPOs and their matched seasoned funds information*/
/*remote connect to WRDS server, dsf is the daily stock file*/
rsubmit;
LibName wComp '/wrds/comp/sasdata/naa';  
LibName wCC '/wrds/crsp/sasdata/a_ccm';
LibName wCRSPD '/wrds/crsp/sasdata/a_stock';
LibName wCRSPA '/wrds/crsp/sasdata/a_indexes';
LibName wCRSP '/wrds/crsp'; run;
endrsubmit;

libname comp slibref=wComp server=wrds;
libname cc slibref=wCC server=wrds;
libname crsp slibref=wcrspd server=wrds;
libname crspa slibref=wcrspa server=wrds;
libname cef "D:\CEF"; run;

data inireturn;
set cef993_cfr;
keep perm fulldate name OP;
run;
/*manually fill in missing offer price. offer price is almost always an integer, so the integer that is closest to the 
closing price should be the offer price.*/
data inireturn;
set inireturn;
if perm=71108 then OP=9.00;
if perm=75159 then OP=14.00;
if perm=75279 then OP=10.00;
if perm=75312 then OP=10.00;
if perm=75324 then OP=10.00;
if perm=75399 then OP=10.00;
if perm=75453 then OP=10.00;
if perm=76398 then OP=10.00;
if perm=77131 then OP=15.00;
if perm=77132 then OP=15.00;
if perm=77133 then OP=15.00;
if perm=77134 then OP=15.00;
if perm=77135 then OP=15.00;
if perm=77136 then OP=15.00;
if perm=77314 then OP=15.00;
if perm=77315 then OP=15.00;
if perm=77316 then OP=15.00;
if perm=77460 then OP=9.00;
if perm=77589 then OP=15.00;
if perm=77590 then OP=15.00;
if perm=77591 then OP=15.00;
if perm=77592 then OP=15.00;
if perm=77638 then OP=15.00;
if perm=77639 then OP=15.00;
if perm=77895 then OP=14.00;
if perm=77923 then OP=15.00;
if perm=77998 then OP=15.00;
if perm=77999 then OP=15.00;
if perm=78094 then OP=15.00;
if perm=79140 then OP=15.00;
if perm=79214 then OP=15.00;
if perm=79353 then OP=10.00;
if perm=79356 then OP=15.00;
if perm=79357 then OP=15.00;
if perm=79358 then OP=15.00;
if perm=79359 then OP=15.00;
if perm=79360 then OP=15.00;
if perm=79361 then OP=15.00;
if perm=79450 then OP=15.00;
if perm=79561 then OP=15.00;
if perm=79650 then OP=15.00;
if perm=79659 then OP=10.00;
if perm=79756 then OP=15.00;
if perm=80207 then OP=10.00;
if perm=80693 then OP=10.00;
if perm=80720 then OP=12.00;
if perm=81035 then OP=8.00;
if perm=81299 then OP=11.00;
if perm=86754 then OP=15.00;
if perm=86944 then OP=15.00;
if perm=87278 then OP=15.00;
if perm=89969 then OP=15.00;
if perm=93249 then OP=25.00;
run;
proc sql;
create table inireturn as select inireturn.*, dsf.prc,dsf.ret,dsf.vol,dsf.shrout,dsf.date,dsf.hexcd
	from inireturn left join crsp.dsf
	on inireturn.perm=dsf.permno & intck('day',inireturn.fulldate,dsf.date)<=70;
quit;
data inireturn;
set inireturn;
if ret=.C then ret1=abs(prc/op)-1;
else if ret ^=.C then ret1=ret;
run;
proc sql;
create table inireturn as select inireturn.*,cef993_cfr.crspvw15,cef993_cfr.nasdaq15 
                           from inireturn left join cef993_cfr
						   on inireturn.perm=cef993_cfr.perm;
quit;						 
proc sort data=inireturn; 
by perm date;
run;
data inireturn; 
set inireturn; 
by perm date;
if first.perm then tradingday = 0 ;
tradingday+1 ;
run;
data inireturn; 
set inireturn; 
format ret1 percent7.4;
run;
proc expand data=inireturn out=inireturn method=none;
by perm; id tradingday;
convert ret1=cumret/transformout=(+1 cuprod -1);
run; 
proc sql;
	create table inireturn as
	select a.*, b.vwretd as crsp
	from inireturn a left join crspa.dsix b
	on a.date=b.caldt;
quit;
data inireturn;
set inireturn;
crsppos=1;
if crsp<=0 then crsppos=0;
run;
proc sort data=inireturn; 
by perm date;
run;
proc expand data=inireturn out=inireturn method=none;
by perm; id tradingday;
convert crsp=cumcrsp/transformout=(+1 cuprod -1);
run; 
data cef.inireturn; 
set inireturn; 
label cumcrsp=cumcrsp
      crsp=crsp;
format cumcrsp percent7.4;
format crsp percent7.4;
run;
data cef.inireturn; 
set cef.inireturn;
if cumcrsp>0 then cumcrsppos=1;
else if cumcrsp<=0 then cumcrsppos=0;
run;
proc corr data=cef.inireturn(where=(tradingday=1 & prc^=.));
var cumcrsppos crsppos;
run;
data cef.inireturn; 
set cef.inireturn; 
if crspvw15>0 then marketup=1;
else if crspvw15<=0 then marketup=0;
if nasdaq15>0 then nasdaqup=1;
else if nasdaq15<=0 then nasdaqup=0;
run;

data stylematchall;
set stylematchall;
if mbegdate>IPOdate+70 then delete;
run;
proc sort data=stylematchall;
*by ipoadr ipodate;
by n_match ipoperm;
run;
proc sql;
create table stylematchall as select a.*, count(ipoperm) as n from stylematchall a
group by ipoperm;
quit;
proc sort data=stylematchall;
*by n;
by ipoperm mbegdate;
run;


proc sql;
create table stylematchall as select stylematchall.*, dsf.prc,dsf.ret,dsf.date
	from stylematchall left join crsp.dsf
	on stylematchall.matchper=dsf.permno & dsf.date>=mbegdate & 0<=intck('day',stylematchall.ipodate,dsf.date)<=70;
quit;
proc sort data=stylematchall nodup; 
by n ipoperm matchper date;
run;
data stylematchall1;
set stylematchall;
if date>menddate then delete;
run;
proc sort data=stylematchall1 nodup; 
by n ipoperm date;
run;
proc sort data=stylematchall1 nodup; 
by ipoperm date;
run;
data stylematchall1; 
set stylematchall1; 
by ipoperm date;
if first.ipoperm then tradingday = 0;
tradingday+1;
format ret percent7.4;
run;
proc expand data=stylematchall1 out=stylematchall1 method=none;
by ipoperm; id tradingday;
convert ret=matchcumret/transformout=(+1 cuprod -1);
run; 

proc sql;
	create table inireturn as select a.*, b.matchcumret,b.matchper
	from cef.inireturn a left join stylematchall1 b
	on a.perm=b.ipoperm and a.tradingday=b.tradingday;
quit;
data inireturn;
set inireturn;
label matchcumret='matchcumret';
run;
data inireturn;
set inireturn;
abretmatch=cumret-matchcumret;
format abretmatch percent7.4;
run;
proc transpose data=inireturn(where=(tradingday=10 | tradingday=15 |tradingday=20 |tradingday=25))  
               out=inireturn1(rename=(col1=matchpost10 col2=matchpost15 col3=matchpost20 col4=matchpost25));
var matchcumret;	
by perm;
run;
proc sql;
create table inireturn as select a.*,b.matchpost10,b.matchpost15,matchpost20,matchpost25 from inireturn a left join inireturn1 b
on a.perm=b.perm;
quit;
proc sort data=inireturn nodup; 
by perm tradingday;
run;
data inireturn; 
set inireturn; 
if matchpost10>0 then matchpost10up=1;
else if matchpost10<=0 then matchpost10up=0;
if matchpost15>0 then matchpost15up=1;
else if matchpost15<=0 then matchpost15up=0;
if matchpost20>0 then matchpost20up=1;
else if matchpost20<=0 then matchpost20up=0;
if matchpost25>0 then matchpost25up=1;
else if matchpost25<=0 then matchpost25up=0;
run;
proc sort data=inireturn; 
by matchpost10up tradingday;
run;

/*top two figures: stock funds*/
proc sql;
create table inireturn_adr as select a.*, b.adr from inireturn a left join cefipomonth b
on a.perm=b.perm;
quit;
proc sort data=inireturn_adr nodup;
by perm tradingday;
run;
proc sort data=inireturn_adr; 
by postipo20up tradingday;
run;
proc means data=inireturn_adr(where=(cumret^=. & matchcumret^=. & ADR^=5 & ADR^=6))noprint;
  class postipo20up tradingday; 
  var cumret matchcumret abretmatch;
  output out=inireturn_adrstat 
  mean= median= t= /autoname;
run;
proc sort data=inireturn_adrstat;
by tradingday;
run;
data inireturn_adrstat1;
set inireturn_adrstat;
*if adr=. then delete;
if tradingday=. then delete;
if postipo20up=. then delete;
format cumret_mean percent7.4;
format matchcumret_mean percent7.4;
format abretmatch_mean percent7.4;
format cumret_median percent7.4;
format matchcumret_median percent7.4;
format abretmatch_median percent7.4;
run;
data inireturn_adrstat1;
length group $25.;
set inireturn_adrstat1;
if postipo20up=1 then group='Stock Market Goes Up' ;
else if postipo20up=0 then group='Stock Market Goes Down';
run;
proc sort data=inireturn_adrstat1;
by tradingday;
run;

options date orientation=landscape; ods pdf file='D:\CEF\non-bond CEF IPO cumulative raw return by 20 trading day Post CEF IPO CRSP Up or Down.pdf';
goptions device=pdfc; /* Plot Saved in Home Directory */
axis1 label=(angle=90 "Buy-and-hold Raw Return in %")
      order=(-0.08 to 0.02 by 0.01);
axis2 label=("Trading Day")
      order=(1 to 40);
symbol1 interpol=join color=red value=none line=5 width=2;
symbol2 interpol=join color=green value=plus line=1 width=2;
symbol3 interpol=join color=blue value=marker line=3 width=2;
symbol4 interpol=join color=black value=star line=8 width=2;
*symbol5 interpol=join color=yellow value=cube line=1 width=2;
legend1 label=('buy-and-hold raw return:') value=(color=black /*'daily return' 'cumulative daily return'*/);
proc gplot data =inireturn_adrstat1;
Title "Buy-and-Hold Raw Return of CEF IPOs from 1986 to 2013";
*title2 "on average and in aggregate";
*by adr;
plot (cumret_mean cumret_median)*tradingday=group
       /overlay legend=legend1 vref=0 href=20 vaxis=axis1 haxis=axis2;
run;quit; ods pdf close; 
options date orientation=landscape; ods pdf file='P:\CEF Investor\non-bond CEF IPO cumulative adjusted return by 20 trading day Post CEF IPO CRSP Up or Down.pdf';
goptions device=pdfc; /* Plot Saved in Home Directory */
axis1 label=(angle=90 "Buy-and-hold Abnormal Return in %")
      order=(-0.08 to 0.02 by 0.01);
axis2 label=("Trading Day")
      order=(1 to 40 by 3);
symbol1 interpol=join color=red value=none line=5 width=2;
symbol2 interpol=join color=green value=plus line=1 width=2;
*symbol3 interpol=join color=blue value=marker line=1 width=2;
*symbol4 interpol=join color=black value=star line=1 width=2;
*symbol5 interpol=join color=yellow value=cube line=1 width=2;
legend1 label=('buy-and-hold abnormal return relative to size-matched seasoned funds:') value=(color=black /*'daily return' 'cumulative daily return'*/);
proc gplot data =inireturn_adrstat1;
Title "Buy-and-Hold Abnormal Return of CEF IPOs from 1986 to 2013";
*title2 "on average and in aggregate";
*by adr;
plot (abretmatch_mean abretmatch_median)*tradingday=group
       /overlay legend=legend1 vref=0 href=20 vaxis=axis1 haxis=axis2;
run;quit; ods pdf close; 

/*bottom two figures: bond funds*/
proc means data=inireturn_adr(where=(cumret^=. & matchcumret^=. & 7>ADR>4))noprint;
  class postipo20up tradingday; 
  var cumret matchcumret abretmatch;
  output out=inireturn_adrstat 
  mean= median= t= /autoname;
run;
proc sort data=inireturn_adrstat;
by tradingday;
run;
data inireturn_adrstat1;
set inireturn_adrstat;
*if adr=. then delete;
if tradingday=. then delete;
if postipo20up=. then delete;
format cumret_mean percent7.4;
format matchcumret_mean percent7.4;
format abretmatch_mean percent7.4;
format cumret_median percent7.4;
format matchcumret_median percent7.4;
format abretmatch_median percent7.4;
run;
data inireturn_adrstat1;
length group $25.;
set inireturn_adrstat1;
if postipo20up=1 then group='Stock Market Goes Up' ;
else if postipo20up=0 then group='Stock Market Goes Down';
run;
proc sort data=inireturn_adrstat1;
by tradingday;
run;

options date orientation=landscape; ods pdf file='D:\CEF\bond CEF IPO cumulative raw return by 20 trading day Post CEF IPO CRSP Up or Down.pdf';
goptions device=pdfc; /* Plot Saved in Home Directory */
axis1 label=(angle=90 "Buy-and-hold Raw Return in %")
      order=(-0.08 to 0.02 by 0.01);
axis2 label=("Trading Day")
      order=(1 to 40);
symbol1 interpol=join color=red value=none line=5 width=2;
symbol2 interpol=join color=green value=plus line=1 width=2;
symbol3 interpol=join color=blue value=marker line=3 width=2;
symbol4 interpol=join color=black value=star line=8 width=2;
*symbol5 interpol=join color=yellow value=cube line=1 width=2;
legend1 label=('buy-and-hold raw return:') value=(color=black /*'daily return' 'cumulative daily return'*/);
proc gplot data =inireturn_adrstat1;
Title "Buy-and-Hold Raw Return of CEF IPOs from 1986 to 2013";
*title2 "on average and in aggregate";
*by adr;
plot (cumret_mean)*tradingday=group
       /overlay legend=legend1 vref=0 href=20 vaxis=axis1 haxis=axis2;
run;quit; ods pdf close; 
options date orientation=landscape; ods pdf file='D:\CEF\bond CEF IPO cumulative adjusted return by 20 trading day Post CEF IPO CRSP Up or Down.pdf';
goptions device=pdfc; /* Plot Saved in Home Directory */
axis1 label=(angle=90 "Buy-and-hold Abnormal Return in %")
      order=(-0.08 to 0.02 by 0.01);
axis2 label=("Trading Day")
      order=(1 to 40 by 3);
symbol1 interpol=join color=red value=none line=5 width=2;
symbol2 interpol=join color=green value=plus line=1 width=2;
*symbol3 interpol=join color=blue value=marker line=1 width=2;
*symbol4 interpol=join color=black value=star line=1 width=2;
*symbol5 interpol=join color=yellow value=cube line=1 width=2;
legend1 label=('buy-and-hold abnormal return relative to size-matched seasoned funds:') value=(color=black /*'daily return' 'cumulative daily return'*/);
proc gplot data =inireturn_adrstat1;
Title "Buy-and-Hold Abnormal Return of CEF IPOs from 1986 to 2013";
*title2 "on average and in aggregate";
*by adr;
plot (abretmatch_mean)*tradingday=group
       /overlay legend=legend1 vref=0 href=20 vaxis=axis1 haxis=axis2;
run;quit; ods pdf close; 


/**********************************************************************************************************/
/********************Figure 5, Number of CEF IPO by Day of Month*******************************************/
/**********************************************************************************************************/

/*this figure was plotted using Excel, by plotting the number of CEF IPOs in each asset class against each calendar day in a month. 
	Specifically, in the cef993_cfr file, the asset class and date of each CEF IPO is given.*/


/**********************************************************************************************************/
/********************Table 2, CEF IPO Premium, Calendar-Time Results, 1986-2013****************************/
/**********************************************************************************************************/

/*to change value-weighted or equal-weighted, comment on "weight cefmcap". 
	to change the number of CEFs in a portfolio, comment on "if pord_n<1 then delete".*/
proc sort data=cef993nav_cfr;
by adr ipoperm date;
run;
proc means data=cef993nav_cfr(where=(pord^=. and (evtmonth4<=1 or old=1)/*and '01Jan1993'd<=date<='31Dec2004'd*/)) noprint;
  class adr date old; 
  *weight cefmcap;
  var pord;
  output out=ceftable_a2_stat 
  mean= n= t= /autoname;
run;
data ceftable_a2_stat;
set ceftable_a2_stat;
if old=. then delete;
if date=. then delete;
*if pord_n<1 then delete;
if pord_n<2 then delete;
format pord_mean percent7.4;
run;
proc sort data=ceftable_a2_stat;
by adr date old;
run;
data cef993ipoadr;
set ceftable_a2_stat;
if old=0;
rename pord_mean=ipo_pord;
run;
data cef993seasonedadr;
set ceftable_a2_stat;
if old=1;
rename pord_mean=seasoned_pord;
run;
proc sql;
create table cef993calendaradr as select a.*, b.seasoned_pord,b.date as date1,b.pord_n as n_seasoned from cef993ipoadr a full join cef993seasonedadr b
on a.date=b.date and a.adr=b.adr;
quit;
data cef993calendaradr;
set cef993calendaradr;
if date=. then date=date1;
label seasoned_pord=seasoned_pord
      ipo_pord=ipo_pord
	  n_seasoned=n_seasoned;
drop old _type_ _freq_ pord_t;
run;
data cef993calendaradr;
 set cef993calendaradr;
drop date1;
rename pord_n=n_ipo;
label n_ipo=n_ipo;
if adr=. then delete;
run;
data cef993calendaradr;
set cef993calendaradr;
diff=ipo_pord-seasoned_pord;
format diff percent7.4;
if ADR=3 then fundtype='Domestic Equity';
else if ADR=4 then fundtype='Foreign Equity';
else if ADR=5 then fundtype='Muni';
else if ADR=6 then fundtype='Taxable FI';
else if ADR=7 then fundtype='Others';
run;
proc sort data=cef993calendaradr;
by adr date;
run;
proc means data=cef993calendaradr(where=(diff^=.))noprint;
  class fundtype; 
  var diff ipo_pord seasoned_pord;
  output out=cef993calendaradr_stat1 
  mean= stderr= t= /autoname;
run;


/**********************************************************************************************************/
/********************Table 5, CEF IPO Performance, Calendar-Time Results, 1986-2013************************/
/********************Table A1 CEF IPO Performance, Calendar-Time Results, ending in 2004*******************/
/**********************************************************************************************************/

/*to get value-weighted results, use "weight cefmcap". 
  to restrict the number of CEFs in a portfolio, change "if _freq_<1 then delete". to "if _freq_<2 then delete" etc.
  to get results reported in Table A1, change the date range accordingly*/

proc means data=cef993nav_cfr(where=(ret^=. and old ^=.)) noprint;
  class adr date old; 
  *weight cefmcap;
  var ret;
  output out=cef993nav_adrstat 
  mean= t= /autoname;
run;
data cef993nav_adrstat1;
set cef993nav_adrstat;
if adr=. then delete;
if old=. then delete;
if date=. then delete;
if _freq_<1 then delete;
format ret_mean percent7.4;
run;
proc sort data=cef993nav_adrstat1;
by adr date old;
run;
data cef993ipoadr;
set cef993nav_adrstat1;
if old=0;
rename ret_mean=ipo_ret;
rename _freq_=n_ipo;
run;
data cef993seasonedadr;
set cef993nav_adrstat1;
if old=1;
rename ret_mean=seasoned_ret;
rename _freq_=n_seasoned;
run;
proc sql;
create table cef993calendaradr as select a.*, b.seasoned_ret,b.date as date1,b.n_seasoned from cef993ipoadr a full join cef993seasonedadr b
on a.date=b.date and a.adr=b.adr;
quit;
data cef993calendaradr;
set cef993calendaradr;
if date=. then date=date1;
label seasoned_ret=seasoned_ret
      ipo_ret=ipo_ret;
drop old _type_ ret_t;
run;
data cef993calendaradr;
set cef993calendaradr;
drop date1;
if adr=. then delete;
run;
proc sort data=cef993calendaradr;
by adr date;
run;
data cef993calendaradr;
set cef993calendaradr;
retdiff=ipo_ret-seasoned_ret;
format retdiff percent7.4;
run;
proc means data=cef993calendaradr(where=(retdiff^=.))noprint;
  class ADR; 
  var retdiff;
  output out=cef993calendaradr_stat1 
  mean= t= stderr=/autoname;
run;

/**********************************************************************************************************/
/********************Table 8, Average First-day Turnover for CEFs, 1986-2013*******************************/
/**********************************************************************************************************/
libname cef "D:\CEF"; run;

data cef.inireturn;
set cef.inireturn;
vol1=vol;
if hexcd=3 & year(date)<2001 then vol1=vol/2;
else if hexcd=3 & year(date)=2001 & month(date)=1 then vol1=vol/2;
else if hexcd=3 & year(date)=2001 & month(date)>1 then vol1=vol/1.8;
else if hexcd=3 & 2002<=year(date)<=2003 then vol1=vol/1.6;
run;
data cef.inireturn;
set cef.inireturn;
turnover1=vol1/(shrout*1000);
format turnover1 percent7.4;
run;
data cef.inireturn;
set cef.inireturn;
year=year(fulldate);
run;
proc sort data=cef.inireturn nodup;
by year hexcd tradingday;
run;
proc means data=cef.inireturn (where=(turnover1^=. & tradingday=1))noprint;
  class year hexcd tradingday; 
  *weight size;
  *var turnover;
  var turnover1;
  output out=turnoverday1_stat 
  mean= n= t= sum=/autoname;
run;
proc sort data=turnoverday1_stat;
by year hexcd tradingday;
run;
data turnoverday1_stat1;
set turnoverday1_stat;
if tradingday=. then delete;
if year=. then delete;
if hexcd=. then delete;
*if marketup=. then delete;
if hexcd=1 then Exchange='NYSE';
else if hexcd=2 then Exchange='Amex';
else if hexcd=3 then Exchange='Nasdaq';
run;

/**********************************************************************************************************/
/********************Table 9, Institutional Ownership in CEF, Calendar-Time Results, 1986-2013*************/
/**********************************************************************************************************/

/*Table 9, Panel A, first 6-month post-IPO*/
proc means data=cef993nav_cfr(where=(evtmonth4<=6 and instown_perc^=. and instown_perc<=1)) noprint;
  class adr; 
  var instown_perc;
  output out=cef993nav_stat 
  mean= n= t= sum=/autoname;
run;
proc sort data=cef993nav_stat;
by adr;
run;
data cef993nav_stat;
set cef993nav_stat;
format instown_perc_mean percent7.4;
run;

/*Table 9, Panel B, after the first 6-month post-IPO*/
proc means data=cef993nav_cfr(where=(evtmonth4>6 and instown_perc^=. and instown_perc<=1)) noprint;
  class adr; 
  var instown_perc;
  output out=cef993nav_stat 
  mean= median= max= n= t= sum=/autoname;
run;
proc sort data=cef993nav_stat;
by adr;
run;
data cef993nav_stat;
set cef993nav_stat;
format instown_perc_mean percent7.4;
run;

/**********************************************************************************************************/
/********************Table A2, Premium/Discount of CEF IPOs and Premium-Matched Seasoned Funds*************/
/**********************************************************************************************************/

/*premiummatchall dataset includes the CEF IPO perm, CEF IPO premium or discount at the time of IPO, and 
  the same information of premium-matched seasoned fund in the same asset class.
  to remove the restriction on IPO premium, comment out "ipopord<0.2". */
proc means data=premiummatchall(where=(/*ipopord<0.2 &*/ ipopord^=. & mpord^=.));
class IPOADR;
var ipopord mpord;
run;



